[−][src]Enum unicode_types::nandinagari::Nandinagari
An enum to represent all characters in the Nandinagari block.
Variants
LetterA\u{119a0}: '𑦠'
LetterAa\u{119a1}: '𑦡'
LetterI\u{119a2}: '𑦢'
LetterIi\u{119a3}: '𑦣'
LetterU\u{119a4}: '𑦤'
LetterUu\u{119a5}: '𑦥'
LetterVocalicR\u{119a6}: '𑦦'
LetterVocalicRr\u{119a7}: '𑦧'
LetterE\u{119aa}: '𑦪'
LetterAi\u{119ab}: '𑦫'
LetterO\u{119ac}: '𑦬'
LetterAu\u{119ad}: '𑦭'
LetterKa\u{119ae}: '𑦮'
LetterKha\u{119af}: '𑦯'
LetterGa\u{119b0}: '𑦰'
LetterGha\u{119b1}: '𑦱'
LetterNga\u{119b2}: '𑦲'
LetterCa\u{119b3}: '𑦳'
LetterCha\u{119b4}: '𑦴'
LetterJa\u{119b5}: '𑦵'
LetterJha\u{119b6}: '𑦶'
LetterNya\u{119b7}: '𑦷'
LetterTta\u{119b8}: '𑦸'
LetterTtha\u{119b9}: '𑦹'
LetterDda\u{119ba}: '𑦺'
LetterDdha\u{119bb}: '𑦻'
LetterNna\u{119bc}: '𑦼'
LetterTa\u{119bd}: '𑦽'
LetterTha\u{119be}: '𑦾'
LetterDa\u{119bf}: '𑦿'
LetterDha\u{119c0}: '𑧀'
LetterNa\u{119c1}: '𑧁'
LetterPa\u{119c2}: '𑧂'
LetterPha\u{119c3}: '𑧃'
LetterBa\u{119c4}: '𑧄'
LetterBha\u{119c5}: '𑧅'
LetterMa\u{119c6}: '𑧆'
LetterYa\u{119c7}: '𑧇'
LetterRa\u{119c8}: '𑧈'
LetterLa\u{119c9}: '𑧉'
LetterVa\u{119ca}: '𑧊'
LetterSha\u{119cb}: '𑧋'
LetterSsa\u{119cc}: '𑧌'
LetterSa\u{119cd}: '𑧍'
LetterHa\u{119ce}: '𑧎'
LetterLla\u{119cf}: '𑧏'
LetterRra\u{119d0}: '𑧐'
VowelSignAa\u{119d1}: '𑧑'
VowelSignI\u{119d2}: '𑧒'
VowelSignIi\u{119d3}: '𑧓'
VowelSignU\u{119d4}: '𑧔'
VowelSignUu\u{119d5}: '𑧕'
VowelSignVocalicR\u{119d6}: '𑧖'
VowelSignVocalicRr\u{119d7}: '𑧗'
VowelSignE\u{119da}: '𑧚'
VowelSignAi\u{119db}: '𑧛'
VowelSignO\u{119dc}: '𑧜'
VowelSignAu\u{119dd}: '𑧝'
SignAnusvara\u{119de}: '𑧞'
SignVisarga\u{119df}: '𑧟'
SignVirama\u{119e0}: '𑧠'
SignAvagraha\u{119e1}: '𑧡'
SignSiddham\u{119e2}: '𑧢'
Headstroke\u{119e3}: '𑧣'
VowelSignPrishthamatraE\u{119e4}: '𑧤'
Methods
impl Nandinagari[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case